==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/gm_logo.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	gm_logo.lang.inc.php 2015-08-25 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'GM_LOGO_CURRENT' => 'Aktuelle Datei',
	'GM_LOGO_DELETE' => 'Datei löschen',
	'GM_LOGO_FILE_DELETED' => 'Die Datei wurde gelöscht.',
	'GM_LOGO_FILE_EXISTS' => 'Es ist bereits ein Logo mit demselben Dateinamen in einem anderen Bereich vorhanden. Bitte benennen Sie die Datei vor dem Hochladen um.',
	'GM_LOGO_FILE_STATUS' => 'Der Dateistatus wurde geändert.',
	'GM_LOGO_FILETYP_WRONG' => 'Der Dateityp ist nicht erlaubt.',
	'GM_LOGO_IMAGES_DIRECTORY_DOES_NOT_EXIST' => 'Fehler: Das Verzeichnis \'images\' im Katalogverzeichnis ist nicht vorhanden: ',
	'GM_LOGO_IMAGES_DIRECTORY_NOT_WRITEABLE' => 'Fehler: Das Verzeichnis \'images\' im Katalogverzeichnis ist schreibgeschützt: ',
	'GM_LOGO_IMAGES_LOGOS_DIRECTORY_DOES_NOT_EXIST' => 'Fehler: Das Verzeichnis \'images/logos\' im Katalogverzeichnis ist nicht vorhanden: ',
	'GM_LOGO_IMAGES_LOGOS_DIRECTORY_NOT_WRITEABLE' => 'Fehler: Das Verzeichnis \'images/logos\' im Katalogverzeichnis ist schreibgeschützt: ',
	'GM_LOGO_UPLOAD' => 'Datei hochladen',
	'GM_LOGO_UPLOAD_SUCCEEDED' => 'Die Datei konnte erfolgreich hochgeladen werden.',
	'GM_LOGO_USE' => 'Datei verwenden',
	'HEADING_SUB_TITLE' => 'Gambio',
	'HEADING_TITLE' => 'Logo Manager',
	'MENU_TITLE_GM_LOGO_CAT' => 'Kategorie Icon',
	'MENU_TITLE_GM_LOGO_FAVICON' => 'Favicon',
	'MENU_TITLE_GM_LOGO_FAVICON_IPAD' => 'Apple Touch Icon',
	'MENU_TITLE_GM_LOGO_FLASH' => 'Flash Logo',
	'MENU_TITLE_GM_LOGO_MAIL' => 'E-Mail Logo',
	'MENU_TITLE_GM_LOGO_OVERLAY' => 'Wasserzeichen',
	'MENU_TITLE_GM_LOGO_PDF' => 'Rechnungs Logo',
	'MENU_TITLE_GM_LOGO_SHOP' => 'Shop Logo',
	'TITLE_FAILED' => 'Fehler',
	'TITLE_SUCCESS' => 'Aktualisiert'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/gm_logo.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	gm_logo.lang.inc.php 2015-08-25 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'GM_LOGO_CURRENT' => 'Aktuelle Datei',
	'GM_LOGO_DELETE' => 'Datei löschen',
	'GM_LOGO_FILE_DELETED' => 'Die Datei wurde gelöscht.',
	'GM_LOGO_FILE_EXISTS' => 'Es ist bereits ein Logo mit demselben Dateinamen in einem anderen Bereich vorhanden. Bitte benenne die Datei vor dem Hochladen um.',
	'GM_LOGO_FILE_STATUS' => 'Der Dateistatus wurde geändert.',
	'GM_LOGO_FILETYP_WRONG' => 'Der Dateityp ist nicht erlaubt.',
	'GM_LOGO_IMAGES_DIRECTORY_DOES_NOT_EXIST' => 'Fehler: Das Verzeichnis \'images\' im Katalogverzeichnis ist nicht vorhanden: ',
	'GM_LOGO_IMAGES_DIRECTORY_NOT_WRITEABLE' => 'Fehler: Das Verzeichnis \'images\' im Katalogverzeichnis ist schreibgeschützt: ',
	'GM_LOGO_IMAGES_LOGOS_DIRECTORY_DOES_NOT_EXIST' => 'Fehler: Das Verzeichnis \'images/logos\' im Katalogverzeichnis ist nicht vorhanden: ',
	'GM_LOGO_IMAGES_LOGOS_DIRECTORY_NOT_WRITEABLE' => 'Fehler: Das Verzeichnis \'images/logos\' im Katalogverzeichnis ist schreibgeschützt: ',
	'GM_LOGO_UPLOAD' => 'Datei hochladen',
	'GM_LOGO_UPLOAD_SUCCEEDED' => 'Die Datei konnte erfolgreich hochgeladen werden.',
	'GM_LOGO_USE' => 'Datei verwenden',
	'HEADING_SUB_TITLE' => 'Gambio',
	'HEADING_TITLE' => 'Logo Manager',
	'MENU_TITLE_GM_LOGO_CAT' => 'Kategorie Icon',
	'MENU_TITLE_GM_LOGO_FAVICON' => 'Favicon',
	'MENU_TITLE_GM_LOGO_FAVICON_IPAD' => 'Apple Touch Icon',
	'MENU_TITLE_GM_LOGO_FLASH' => 'Flash Logo',
	'MENU_TITLE_GM_LOGO_MAIL' => 'E-Mail Logo',
	'MENU_TITLE_GM_LOGO_OVERLAY' => 'Wasserzeichen',
	'MENU_TITLE_GM_LOGO_PDF' => 'Rechnungs Logo',
	'MENU_TITLE_GM_LOGO_SHOP' => 'Shop Logo',
	'TITLE_FAILED' => 'Fehler',
	'TITLE_SUCCESS' => 'Aktualisiert'
);
